@@ -42,6 +42,10 @@ class ZIDS_Dag():
         # For Stg and Prd environments, we want DAG to be created and immediately be active
         self.start_as_paused = True
 
+        #override conrol of the basic dag config
+        self.dag_retry_delay = 5
+        self.dag_schedule_interval = "@daily"
+
         env_type = os.environ.get('SPRING_PROFILES_ACTIVE')
         if (env_type == 'production') or (env_type == 'staging'):
             self.start_as_paused = False
@@ -87,15 +91,16 @@ class ZIDS_Dag():
         extra_dag_job_params = json_dumps({"MODE": "AIRFLOW", "TEST_EXEC_DATE": "{{ next_execution_date }}"})
         
         now = datetime.now().replace(hour=0, minute=0, second=0, microsecond=0)
-        now = now - timedelta(days=1)
+        dag_start_date = now - timedelta(days=''' + str(self.dag_start_delay) + ''')
+        
         # STEP 3: Set default arguments for the DAG
         default_dag_args = {
-            'start_date': now,
+            'start_date': dag_start_date,
             'depends_on_past': False,
             'email_on_failure': False,
             'email_on_retry': False,
             'retries': 1,
-            'retry_delay': timedelta(minutes=5)
+            'retry_delay': timedelta(minutes=''' + str(self.dag_retry_delay) + ''')
         }
         # Define a DAG (directed acyclic graph) of tasks.
         # Any task you create within the context manager is automatically added to the
@@ -104,7 +109,7 @@ class ZIDS_Dag():
             orig_project_name + '_' + target + '_workflow_dag',
             description='DAG for deployment a Dataproc Cluster for ' + project_id,
             # schedule_interval=timedelta(days=1),
-            schedule_interval='@daily',
+            schedule_interval="''' + str(self.dag_schedule_interval) + '''",
             default_args=default_dag_args,
             is_paused_upon_creation=''' + str(self.start_as_paused) + '''
         ) as dag:
