@@ -165,7 +165,7 @@ def write_output(output: List[Dict], output_path):
     bucket_name, file_path = parse_s3_url(output_path)
     with io.StringIO() as csvfile:
     # with open(output_path, 'w', newline='') as csvfile:
-        fieldnames = list(output[0].keys())
+        fieldnames = service_client.get_csv_field_names()  # list(output[0].keys())
         writer = csv.DictWriter(csvfile, fieldnames=fieldnames, quotechar='"')
 
         writer.writeheader()
