@@ -81,8 +81,8 @@ class ZIDS_Tester:
         # Call the model to get predictions
         predicted_records = self.pipeline.execute(**model_request)
         parsed_row_data_frame = {}
-        for title in row_dataframe.columns[1:]:
-            parsed_row_data_frame[title] = row_dataframe.iloc[0][title]
+        for index, row in list(row_dataframe.iterrows()):
+            parsed_row_data_frame = dict(row)
         pred_tmp = {'pred_model' : json.dumps(predicted_records.dict()),
                     'target': json.dumps(parsed_row_data_frame)
                     }
